% <CustomTools>
%   <Menu>
%     <Item name="AddIDStatistics" icon="Matlab" tooltip="Adds a new Statistics value ID to the selected spots or surface component">
%       <Command>MatlabXT::AddIDStatistics(%i)</Command>
%     </Item>
%   </Menu>
% </CustomTools>

function AddIDStatistics(aImarisApplicationID)

if ~isa(aImarisApplicationID, 'Imaris.IApplicationPrxHelper')
  javaaddpath ImarisLib.jar
  vImarisLib = ImarisLib;
  if ischar(aImarisApplicationID)
	  aImarisApplicationID = round(str2double(aImarisApplicationID));
  end
  vImarisApplication = vImarisLib.GetApplication(aImarisApplicationID);
else
  vImarisApplication = aImarisApplicationID;
end


if isequal(vImarisApplication, [])
  display('Could not connect to Imaris')
  return
end

vSelection = vImarisApplication.GetSurpassSelection;

vSpots = vImarisApplication.GetFactory.ToSpots(vSelection);
vSurfaces = vImarisApplication.GetFactory.ToSurfaces(vSelection);
vCategory = '';
if isequal(vSpots, []) && isequal(vSurfaces, [])
  display('No spots or surfaces selected')
  return
end

vComponentName = char(vSelection.GetName);
vNumberOfItems = 0;

vItemIndicesT = zeros(vNumberOfItems,1);
if ~isequal(vSpots, [])
  vItemIndicesT = vSpots.GetIndicesT;
  vNumberOfItems = size(vItemIndicesT,1);
  vCategory = 'Spot';
end

if ~isequal(vSurfaces, [])
  vCategory = 'Surface';
  vNumberOfItems = vSurfaces.GetNumberOfSurfaces();
  for vSurfaceIndex = 1:vNumberOfItems
    vItemIndicesT(vSurfaceIndex) = vSurfaces.GetTimeIndex(vSurfaceIndex-1);
  end
end

vTemplate = cell(vNumberOfItems,1);

vNames = vTemplate;
vValues = (0:vNumberOfItems-1)';
vUnits = cell(vNumberOfItems,1);
vFactors = cell(2, vNumberOfItems);
vFactorNames = {'Category'; 'Time'};
vIDs = (0:vNumberOfItems-1)';

for i=1:vNumberOfItems
  vNames{i} = 'ID';
  vUnits{i} = '';
  vFactors{1,i} = vCategory;
  vFactors{2,i} = char(num2str(vItemIndicesT(i))+1);
end


vSelection.AddStatistics(vNames, vValues, vUnits, vFactors, vFactorNames, vIDs);

sprintf('Added Statistics named ID to the %d %ss of %s', vNumberOfItems, vCategory, vComponentName);
